@@ -5,10 +5,7 @@ from LMS.TitleConfig.Definitions.Value import ValueDefinition
 
 @dataclass(frozen=True)
 class AttributeConfig:
-    """Class that represents an attribute structure definition.
-
-    Configs may have multiple, linked to the if a game has multiple MSBP files."""
-
+    """Class that represents an attribute config definition"""
     name: str
     description: str = field(repr=False)
     definitions: list[ValueDefinition]
